==> prestashop_1.4.0.17.zip: prestashop/modules/statsgeolocation/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_323d4eb70b252acb4a04eaf9e0882597'] = 'Geotargeting';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_621bd20bc26d0f67bacffc7785616372'] = 'Anzeige des Kundenstandorts';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_60503475047260bb2e6b815e3dcad910'] = 'Dieses Modul zeigt die Länderverteilung der Kunden durch Punkte in verschiedenen Größen auf der Weltkarte an. Zeigen Sie den Ruf Ihrer Webseite rund um die Welt an sowie die Kontinente, die Sie noch nicht erobert haben.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_e346362c256cd1ff6efd70288f769d89'] = 'Ein Tor zur Welt';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_1b625393440dce51a25ccb43a38ddf67'] = 'Hinzufügen neuer Sprachen zu Ihrem Shop, wenn Sie sehen, dass ein ausreichender Teil Ihrer Kunden aus dem Ausland kommt.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_a2f24ad94046ee38db78c336564acd30'] = 'Vergrößern Sie Ihre Versand-Bereich, um der potenziellen Nachfrage gerecht zu werden.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_25e8f2fd2871c8423bbe4e254066cd98'] = 'Bitte warten ...';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_e7173e323991c8c33ad2dae1d528fc2e'] = 'Koordinaten aktualisieren';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_60e421611f85e8faa9f6950ce71dab7a'] = 'Klicken Sie auf einen Ländernamen und bestimmen Sie seine Position auf der Karte';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_64d80b7a177f4bd0a1f1dde09741852d'] = 'Klicken Sie auf die Karte, um die Position von   einzustellen:';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_dc25612aeb2ba1c2705fc2e9c947f084'] = 'Fehler: Sie müssen auf die Karte klicken oder auf die Schaltfläche Abbrechen';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_ad3d06d03d94223fa652babc913de686'] = 'Bestätigen';

==> prestashop_1.4.4.1.zip: prestashop/modules/statsgeolocation/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_323d4eb70b252acb4a04eaf9e0882597'] = 'Geotargeting';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_621bd20bc26d0f67bacffc7785616372'] = 'Anzeige des Kundenstandorts';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_60503475047260bb2e6b815e3dcad910'] = 'Dieses Modul zeigt die Länderverteilung der Kunden durch Punkte in verschiedenen Größen auf der Weltkarte an. Zeigen Sie den Ruf Ihrer Webseite rund um die Welt an sowie die Kontinente, die Sie noch nicht erobert haben.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_6602bbeb2956c035fb4cb5e844a4861b'] = 'Erklärung';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_e346362c256cd1ff6efd70288f769d89'] = 'Ein Tor zur Welt';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_1b625393440dce51a25ccb43a38ddf67'] = 'Hinzufügen neuer Sprachen zu Ihrem Shop, wenn Sie sehen, dass ein ausreichender Teil Ihrer Kunden aus dem Ausland kommt.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_a2f24ad94046ee38db78c336564acd30'] = 'Vergrößern Sie Ihre Versand-Bereich, um der potenziellen Nachfrage gerecht zu werden.';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_25e8f2fd2871c8423bbe4e254066cd98'] = 'Bitte warten ...';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_e7173e323991c8c33ad2dae1d528fc2e'] = 'Koordinaten aktualisieren';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_60e421611f85e8faa9f6950ce71dab7a'] = 'Klicken Sie auf einen Ländernamen und bestimmen Sie seine Position auf der Karte';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_64d80b7a177f4bd0a1f1dde09741852d'] = 'Klicken Sie auf die Karte, um die Position von   einzustellen:';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_dc25612aeb2ba1c2705fc2e9c947f084'] = 'Fehler: Sie müssen auf die Karte klicken oder auf die Schaltfläche Abbrechen';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{statsgeolocation}prestashop>statsgeolocation_ad3d06d03d94223fa652babc913de686'] = 'Bestätigen';
